/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.web.example.model;

import de.conceptpeople.checkerberry.web.environment.ContextProvider;
import de.conceptpeople.checkerberry.web.model.AbstractRemoteControlPage;

/**
 * Model für die Homepage der Test-Web-Anwendung.
 */
public class Navigation extends AbstractRemoteControlPage {

    /**
     * Erzeugt ein neues Model für die Navigation. ES kann generell sinnvoll
     * sein, wiederverwendete Komponenten in eigene Modellklassen auszulagern.
     * 
     * @param contextProvider
     *            Provider für die gesamten Kontextinformationen.
     */
    public Navigation(ContextProvider contextProvider) {
        super(contextProvider);
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createUserlistLink() {
        return createComponentProxy("userListLink");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createLogoutLink() {
        return createComponentProxy("logoutLink");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createLoginLink() {
        return createComponentProxy("loginLink");
    }

    /**
     * Erzeugt eine Fernsteuerung für die entsprechende Komponente.
     * 
     * @return erzeute Proxy-Komponente.
     */
    public BaseComponent createNewUserLink() {
        return createComponentProxy("newUserLink");
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected BaseComponent createComponentProxy(String elementLocator) {
        return new BaseComponent(this, elementLocator);
    }

}
